pub enum B2ClientStatus {
Authed,
KeyExpired,
}Variants
Authed
Default state, and should be the only state if nothing else went wrong.
KeyExpired
The provided key to the client has expired, cannot re-auth, please re-create the client.