B2DeleteFileVersionBody

Struct B2DeleteFileVersionBody 

pub struct B2DeleteFileVersionBody {
    pub file_name: String,
    pub file_id: String,
    pub bypass_governance: Option<bool>,
}

Fields

file_name: String

The name of the file.

file_id: String

The ID of the file, as returned by b2_upload_file, b2_list_file_names, or b2_list_file_versions.

bypass_governance: Option<bool>

Must be specified and set to true if deleting a file version protected by Object Lock governance mode retention settings. Setting the value requires the bypassGovernance application key capability. See Object Lock for more information.

Implementations

Source

impl B2DeleteFileVersionBody

pub fn builder() -> B2DeleteFileVersionBodyBuilder<((), (), ())>

Create a builder for building B2DeleteFileVersionBody. On the builder, call .file_name(...), .file_id(...), .bypass_governance(...)(optional) to set the values of the fields. Finally, call .build() to create the instance of B2DeleteFileVersionBody.