B2UpdateFileRetentionBody

Struct B2UpdateFileRetentionBody 

pub struct B2UpdateFileRetentionBody {
    pub file_name: String,
    pub file_id: String,
    pub file_retention: B2BucketFileRetention,
    pub bypass_governance: Option<bool>,
}

Fields

file_name: String

The name of the file.

file_id: String

The ID of the file.

file_retention: B2BucketFileRetention

Specifies the file retention settings for Backblaze B2 to use for this file. See Object Lock for details.

bypass_governance: Option<bool>

Must be specified and set to true if deleting an existing governance mode retention setting or shortening an existing governance mode retention period. See Object Lock for details.

Implementations

Source

impl B2UpdateFileRetentionBody

pub fn builder() -> B2UpdateFileRetentionBodyBuilder<((), (), (), ())>

Create a builder for building B2UpdateFileRetentionBody. On the builder, call .file_name(...), .file_id(...), .file_retention(...), .bypass_governance(...)(optional) to set the values of the fields. Finally, call .build() to create the instance of B2UpdateFileRetentionBody.