B2DownloadFileQueryParameters

Struct B2DownloadFileQueryParameters 

pub struct B2DownloadFileQueryParameters {
    pub b2_content_disposition: Option<String>,
    pub b2_content_language: Option<String>,
    pub b2_expires: Option<String>,
    pub b2_cache_control: Option<String>,
    pub b2_content_encoding: Option<String>,
    pub b2_content_type: Option<String>,
}

Fields

b2_content_disposition: Option<String>

If this is present, B2 will use it as the value of the ‘Content-Disposition’ header, overriding any ‘b2-content-disposition’ specified when the file was uploaded.

The value must match the grammar specified in RFC 6266. Parameter continuations are not supported. ’Extended-value’s are supported for charset ‘UTF-8’ (case-insensitive) when the language is empty. Note that this file info will not be included in downloads as a x-bz-info-b2-content-disposition header. Instead, it (or the value specified in a request) will be in the Content-Disposition.

If including this header in the response exceeds the 7000-byte overall limit (2048 bytes for files encrypted with SSE), this request will be rejected. See Files for further details about HTTP header size limit.

Requests with this specified must also have an authorization token.

b2_content_language: Option<String>

If this is present, B2 will use it as the value of the ‘Content-Language’ header, overriding any ‘b2-content-language’ specified when the file was uploaded.

The value must match the grammar specified in RFC 2616. Note that this file info will not be included in downloads as a x-bz-info-b2-content-language header. Instead, it (or the value specified in a request) will be in the Content-Language.

If including this header in the response exceeds the 7000-byte overall limit (2048 bytes for files encrypted with SSE), this request will be rejected. See Files for further details about HTTP header size limit.

Requests with this specified must also have an authorization token.

b2_expires: Option<String>

If this is present, B2 will use it as the value of the ‘Expires’ header, overriding any ‘b2-expires’ specified when the file was uploaded.

The value must match the grammar specified in RFC 2616. Note that this file info will not be included in downloads as a x-bz-info-b2-expires header. Instead, it (or the value specified in a request) will be in the Expires.

If including this header in the response exceeds the 7000-byte overall limit (2048 bytes for files encrypted with SSE), this request will be rejected. See Files for further details about HTTP header size limit.

Requests with this specified must also have an authorization token.

b2_cache_control: Option<String>

If this is present, B2 will use it as the value of the ‘Cache-Control’ header, overriding any ‘b2-cache-control’ specified when the file was uploaded.

The value must match the grammar specified in RFC 2616. Note that this file info will not be included in downloads as a x-bz-info-b2-cache-control header. Instead, it (or the value specified in a request) will be in the Cache-Control.

If including this header in the response exceeds the 7000-byte overall limit (2048 bytes for files encrypted with SSE), this request will be rejected. See Files for further details about HTTP header size limit.

Requests with this specified must also have an authorization token.

b2_content_encoding: Option<String>

If this is present, B2 will use it as the value of the ‘Content-Encoding’ header, overriding any ‘b2-content-encoding’ specified when the file was uploaded.

The value must match the grammar specified in RFC 2616. Note that this file info will not be included in downloads as a x-bz-info-b2-content-encoding header. Instead, it (or the value specified in a request) will be in the Content-Encoding.

If including this header in the response exceeds the 7000-byte overall limit (2048 bytes for files encrypted with SSE), this request will be rejected. See Files for further details about HTTP header size limit.

Requests with this specified must also have an authorization token.

b2_content_type: Option<String>

If this is present, B2 will use it as the value of the ‘Content-Type’ header, overriding any ‘Content-Type’ specified when the file was uploaded.

The value must match the grammar specified in RFC 2616. Note that this file info will not be included in downloads as a x-bz-info-b2-content-type header. Instead, it (or the value specified in a request) will be in the Content-Type.

If including this header in the response exceeds the 7000-byte overall limit (2048 bytes for files encrypted with SSE), this request will be rejected. See Files for further details about HTTP header size limit.

Requests with this specified must also have an authorization token.

Implementations

Source

impl B2DownloadFileQueryParameters

pub fn builder() -> B2DownloadFileQueryParametersBuilder<((), (), (), (), (), ())>

Create a builder for building B2DownloadFileQueryParameters. On the builder, call .b2_content_disposition(...)(optional), .b2_content_language(...)(optional), .b2_expires(...)(optional), .b2_cache_control(...)(optional), .b2_content_encoding(...)(optional), .b2_content_type(...)(optional) to set the values of the fields. Finally, call .build() to create the instance of B2DownloadFileQueryParameters.