pub struct B2ListFileNamesQueryParameters {
pub bucket_id: String,
pub start_file_name: Option<String>,
pub max_file_count: Option<NonZeroU32>,
pub prefix: Option<String>,
pub delimiter: Option<String>,
}Fields
bucket_id: StringThe bucket to look for file names in. Returned by b2_list_buckets.
start_file_name: Option<String>The first file name to return. If there is a file with this name, it will be returned in the list. If not, the first file name after this the first one after this name.
max_file_count: Option<NonZeroU32>The maximum number of files to return from this call. The default value is 100, and the maximum is 10000. Passing in 0 means to use the default of 100.
NOTE: b2_list_file_names is a Class C transaction (see Pricing).
The maximum number of files returned per transaction is 1000. If you set maxFileCount to more than 1000 and more than 1000 are returned,
the call will be billed as multiple transactions, as if you had made requests in a loop asking for 1000 at a time. For example:
if you set maxFileCount to 10000 and 3123 items are returned, you will be billed for 4 Class C transactions.
prefix: Option<String>Files returned will be limited to those with the given prefix. Defaults to the empty string, which matches all files.
delimiter: Option<String>Files returned will be limited to those within the top folder, or any one subfolder. Defaults to NULL. Folder names will also be returned. The delimiter character will be used to “break” file names into folders.
Implementations
Sourceimpl B2ListFileNamesQueryParameters
impl B2ListFileNamesQueryParameters
Sourcepub fn builder() -> B2ListFileNamesQueryParametersBuilder<((), (), (), (), ())>
pub fn builder() -> B2ListFileNamesQueryParametersBuilder<((), (), (), (), ())>
Create a builder for building B2ListFileNamesQueryParameters.
On the builder, call .bucket_id(...), .start_file_name(...)(optional), .max_file_count(...)(optional), .prefix(...)(optional), .delimiter(...)(optional) to set the values of the fields.
Finally, call .build() to create the instance of B2ListFileNamesQueryParameters.