pub struct B2ListPartsQueryParameters {
pub file_id: String,
pub start_part_number: Option<u32>,
pub max_part_count: Option<u16>,
}Fields
file_id: StringThe ID returned by b2_start_large_file. This is the file whose parts will be listed.
start_part_number: Option<u32>The first part to return. If there is a part with this number, it will be returned as the first in the list. If not, the returned list will start with the first part number after this one.
max_part_count: Option<u16>The maximum number of parts to return from this call. The default value is 100, and the maximum allowed is 1000.
Implementations
Sourceimpl B2ListPartsQueryParameters
impl B2ListPartsQueryParameters
Sourcepub fn builder() -> B2ListPartsQueryParametersBuilder<((), (), ())>
pub fn builder() -> B2ListPartsQueryParametersBuilder<((), (), ())>
Create a builder for building B2ListPartsQueryParameters.
On the builder, call .file_id(...), .start_part_number(...)(optional), .max_part_count(...)(optional) to set the values of the fields.
Finally, call .build() to create the instance of B2ListPartsQueryParameters.