pub struct B2AuthData {
pub account_id: String,
pub api_info: B2AuthDataApiInfo,
pub authorization_token: String,
pub application_key_expiration_timestamp: Option<u64>,
}Fields
account_id: StringThe identifier for the account.
api_info: B2AuthDataApiInfoA data structure that groups the information you need by API suite.
An authorization token to use with all calls, other than b2_authorize_account, that need an Authorization header. This authorization token is valid for at most 24 hours.
application_key_expiration_timestamp: Option<u64>Expiration timestamp for the application key.