B2ListFileVersionsResponse

Struct B2ListFileVersionsResponse 

pub struct B2ListFileVersionsResponse {
    pub files: Vec<B2File>,
    pub next_file_name: Option<String>,
    pub next_file_id: Option<String>,
}

Fields

files: Vec<B2File>

Array of B2 files.

next_file_name: Option<String>

What to pass in to startFileName for the next search to continue where this one left off, or null if there are no more files. Note this this may not be the name of an actual file, but using it is guaranteed to find the next file version in the bucket.

next_file_id: Option<String>

What to pass in to startFileId for the next search to continue where this one left off, or null if there are no more files. Note this this may not be the ID of an actual file, but using it is guaranteed to find the next file version in the bucket.