pub enum B2Action {
Upload,
Start,
Hide,
Folder,
}Variants
Upload
file that was uploaded to B2 Cloud Storage.
Start
large file has been started, but not finished or canceled.
Hide
file version marking the file as hidden, so that it will not show up in b2_list_file_names.
Folder
is used to indicate a virtual folder when listing files.