pub struct B2AppKey {
pub account_id: String,
pub application_key_id: String,
pub application_key: Option<String>,
pub bucket_id: Option<String>,
pub capabilities: Vec<B2KeyCapability>,
pub expiration_timestamp: Option<u64>,
pub key_name: String,
pub name_prefix: Option<String>,
pub options: Option<Vec<B2BucketOption>>,
}Fields
account_id: StringYour account ID.
application_key_id: StringThe ID of the newly created key.
application_key: Option<String>The secret part of the key. Only returned when creating a new key with b2_create_key.
bucket_id: Option<String>When present, restricts access to one bucket.
capabilities: Vec<B2KeyCapability>The list of capabilities this key has.
expiration_timestamp: Option<u64>When present, says when this key will expire, in milliseconds since 1970.
key_name: StringThe name assigned when the key was created.
name_prefix: Option<String>When present, restricts access to files whose names start with the prefix.
options: Option<Vec<B2BucketOption>>When present and set to s3, the key can be used to sign requests to the S3 Compatible API.