pub struct B2EventNotificationRule {
pub event_types: Vec<B2EventNotificationEventType>,
pub is_enabled: bool,
pub name: String,
pub object_name_prefix: String,
pub is_suspended: Option<bool>,
pub max_events_per_batch: Option<u8>,
pub suspension_reason: Option<String>,
pub target_configuration: B2NotificationConfiguration,
}Fields
event_types: Vec<B2EventNotificationEventType>The list of event types for the event notification rule.
is_enabled: boolWhether the event notification rule is enabled.
name: StringA name for the event notification rule. The name must be unique among the bucket’s notification rules.
object_name_prefix: StringSpecifies which object(s) in the bucket the event notification rule applies to.
is_suspended: Option<bool>Whether the event notification rule is suspended.
max_events_per_batch: Option<u8>Represents the maximum number of events a user will receive per webhook invocation. The value must be a number between 1 and 50. The default value is 1.
suspension_reason: Option<String>A brief description of why the event notification rule was suspended.
target_configuration: B2NotificationConfigurationThe target configuration for the event notification rule.
This object will always contain the targetType`` field. Currently, the only valid value for targetType is "webhook." <br><br>The fields for "webhook" objects are defined below. However, other `targetType values and collections of fields will be available in the future.