pub struct B2NotificationConfiguration {
pub url: String,
pub target_type: B2EventNotificationTargetType,
pub hmac_sha256_signing_secret: Option<String>,
pub custom_headers: Option<HashMap<String, String>>,
}Fields
url: StringThe URL for the webhook.
target_type: B2EventNotificationTargetTypeThe type of the target configuration, currently “webhook” only.
hmac_sha256_signing_secret: Option<String>The signing secret for use in verifying the `X-Bz-Event-Notification-Signature``.
custom_headers: Option<HashMap<String, String>>When present, additional header name/value pairs to be sent on the webhook invocation.