pub struct FileUpload { /* private fields */ }Implementations
Sourceimpl FileUpload
impl FileUpload
pub fn new<F: AsyncFileReader + 'static>( file: F, file_name: String, bucket_id: String, optional_info: Option<HashMap<String, String>>, file_size: u64, options: FileUploadOptions, client: Arc<B2SimpleClient>, ) -> Arc<Self>
pub fn id(&self) -> u64
pub fn stats(&self) -> &FileNetworkStats
pub fn status(&self) -> FileStatus
Sourcepub fn has_stopped(&self) -> bool
pub fn has_stopped(&self) -> bool
Returns true when the file has finished or has been aborted.
Sourcepub async fn start(&self) -> Result<B2File, FileUploadError>
pub async fn start(&self) -> Result<B2File, FileUploadError>
Whether it was started or not, will only start if status is Pending
pub async fn add_finish_callback(&self, callback: B2Callback<()>)