ConstantLargeFileLoadStrategy

Struct ConstantLargeFileLoadStrategy 

pub struct ConstantLargeFileLoadStrategy {
    pub part_size: u64,
    pub chunk_size: u16,
}
Dictates how large file parts are loaded the approximate total bytes of the file that would be loaded at once will equal file_size / chunk_size rounded up to biggest number. part_size must be smaller than the calculated number.


For example, if we take the default values for bytes and chunk_size of 5 Mib and 3, and we’re upload a 500 Mib file the total bytes of the file that would be loaded at once will equal 500 / 3 which is ~166 mibs.

Fields

part_size: u64

size of the file part, from 5 Mib - 5 Gib.
Default 5 Mib.

chunk_size: u16

How many parts are handled per task. must be at least 1.
Default 3.