pub struct Throttle<T: Unsigned + AddAssign + Copy + PartialOrd> { /* private fields */ }Implementations
Sourceimpl<T: Unsigned + AddAssign + Copy + PartialOrd> Throttle<T>
impl<T: Unsigned + AddAssign + Copy + PartialOrd> Throttle<T>
pub fn new(max_per_period: T, period: Duration) -> Self
Sourcepub fn per_second(max_per_period: T) -> Self
pub fn per_second(max_per_period: T) -> Self
Equivalent to
Throttle::new(max_per_period, Duration::from_secs(1))Sourcepub fn per_minute(max_per_period: T) -> Self
pub fn per_minute(max_per_period: T) -> Self
Equivalent to
Throttle::new(max_per_period, Duration::from_secs(60))Sourcepub async fn advance(&mut self) -> T
pub async fn advance(&mut self) -> T
Advances the throttle by 1, waiting if the throttle has been exhausted
Sourcepub async fn advance_by(&mut self, by: T) -> T
pub async fn advance_by(&mut self, by: T) -> T
Advances the throttle by the given amount, waiting if the throttle has been exhausted
Sourcepub async fn wait_if_exhausted(&self)
pub async fn wait_if_exhausted(&self)
If throttle period has been exhausted, waits for the period to end
otherwise returns immediately