pub struct B2ListKeysParameters {
pub account_id: String,
pub max_key_count: Option<u16>,
pub start_application_key_id: Option<String>,
}Fields
account_id: StringThe ID of your account.
max_key_count: Option<u16>The maximum number of files to return from this call. The default value is 100, and the maximum is 10000. Passing in 0 means to use the default of 100.
NOTE: b2_list_keys is a Class C transaction (see Pricing).
The maximum number of files returned per transaction is 1000. If you set maxFileCount to more than 1000 and more than 1000 are returned,
the call will be billed as multiple transactions, as if you had made requests in a loop asking for 1000 at a time. For example:
if you set maxFileCount to 10000 and 3123 items are returned, you will be billed for 4 Class C transactions.
start_application_key_id: Option<String>The first key to return. Used when a query hits the maxKeyCount, and you want to get more. Set to the value returned as the nextApplicationKeyId in the previous query.
Implementations
Sourceimpl B2ListKeysParameters
impl B2ListKeysParameters
Sourcepub fn builder() -> B2ListKeysParametersBuilder<((), (), ())>
pub fn builder() -> B2ListKeysParametersBuilder<((), (), ())>
Create a builder for building B2ListKeysParameters.
On the builder, call .account_id(...), .max_key_count(...)(optional), .start_application_key_id(...)(optional) to set the values of the fields.
Finally, call .build() to create the instance of B2ListKeysParameters.