B2ListUnfinishedLargeFilesQueryParameters

Struct B2ListUnfinishedLargeFilesQueryParameters 

pub struct B2ListUnfinishedLargeFilesQueryParameters {
    pub bucket_id: String,
    pub name_prefix: Option<String>,
    pub start_file_id: Option<String>,
    pub max_file_count: Option<u8>,
}

Fields

bucket_id: String

The bucket to look for file names in.

name_prefix: Option<String>

When a namePrefix is provided, only files whose names match the prefix will be returned. Whe using an application key that is restricted to a name prefix, you must provide a prefix here that is at least as restrictive.

start_file_id: Option<String>

The first upload to return. If there is an upload with this ID, it will be returned in the list. If not, the first upload after this the first one after this ID.

max_file_count: Option<u8>

The maximum number of files to return from this call. The default value is 100, and the maximum allowed is 100.

Implementations

Source

impl B2ListUnfinishedLargeFilesQueryParameters

pub fn builder() -> B2ListUnfinishedLargeFilesQueryParametersBuilder<((), (), (), ())>

Create a builder for building B2ListUnfinishedLargeFilesQueryParameters. On the builder, call .bucket_id(...), .name_prefix(...)(optional), .start_file_id(...)(optional), .max_file_count(...)(optional) to set the values of the fields. Finally, call .build() to create the instance of B2ListUnfinishedLargeFilesQueryParameters.