pub struct B2FilePart {
pub file_id: String,
pub part_number: u16,
pub content_length: u64,
pub content_sha1: String,
pub content_md5: Option<String>,
pub server_side_encryption: B2ServerSideEncryption,
pub upload_timestamp: u64,
}Fields
file_id: StringThe file ID for uploading this file.
part_number: u16Which part this is.
content_length: u64The number of bytes stored in the part.
content_sha1: StringThe SHA1 of the bytes stored in the file as a 40-digit hex string. Large files do not have SHA1 checksums, and the value is “none”. The value is null when the action is “hide”, or “folder”.
content_md5: Option<String>The MD5 of the bytes stored in the part. Not all parts have an MD5 checksum, so this field is optional, and set to null for parts that do not have one.
server_side_encryption: B2ServerSideEncryptionWhen the part is encrypted with Server-Side Encryption, the mode (“SSE-B2” or “SSE-C”) and algorithm used to encrypt the data.
upload_timestamp: u64This is a UTC time when this file was uploaded. It is a base 10 number of milliseconds since midnight, January 1, 1970 UTC. This fits in a 64 bit integer such as the type “long” in the programming language Java. It is intended to be compatible with Java’s time long. For example, it can be passed directly into the java call Date.setTime(long time). Always 0 when the action is “folder”.