pub enum B2EventNotificationEventType {
Show 14 variants
ObjectCreatedUpload,
ObjectCreatedMultipartUpload,
ObjectCreatedCopy,
ObjectCreatedReplica,
ObjectMultipartReplica,
ObjectCreatedAll,
ObjectDeleted,
ObjectDeletedLifecycle,
ObjectDeletedAll,
HideMarkerCreated,
HideMarkerCreatedLifeCycle,
HideMarkerAll,
MultiPartUploadCreatedLiveRead,
MultiPartUploadCreatedAll,
}Expand description
References https://www.backblaze.com/docs/cloud-storage-event-notifications-reference-guide#:~:text=for%20more%20details.-,event%20types,-Backblaze%20B2%20currently
Variants
ObjectCreatedUpload
A new object that is uploaded to Backblaze B2 that is not copied or replicated. This does not include multipart objects.
Resolves to b2:ObjectCreated:Upload
ObjectCreatedMultipartUpload
A multipart object that was completed in Backblaze B2 that was not replicated.
Resolves to b2:ObjectCreated:MultipartUpload
ObjectCreatedCopy
A copied object in Backblaze B2.
Resolves to b2:ObjectCreated:Copy
ObjectCreatedReplica
An object that was replicated in Backblaze B2. This does not include multipart objects. This is the replicated object, and not the source object.
Resolves to b2:ObjectCreated:Replica
ObjectMultipartReplica
A multipart object that was replicated in Backblaze B2. This is the replicated object, and not the source object.
Resolves to b2:ObjectCreated:MultipartReplica
ObjectCreatedAll
Listens to all object creation events.
Resolves to b2:ObjectCreated:*
ObjectDeleted
An object that was deleted by user action, such as with an API call or by using the Backblaze web console.
Resolves to b2:ObjectDeleted:Delete
ObjectDeletedLifecycle
An object that was deleted by a Lifecycle Rule.
Resolves to b2:ObjectDeleted:LifecycleRule
ObjectDeletedAll
Listens to all object deletion events.
Resolves to b2:ObjectCreated:*
HideMarkerCreated
A hide marker that was created by user action, such as with an API call.
Resolves to b2:HideMarkerCreated:Hide
HideMarkerCreatedLifeCycle
A hide marker that was created by a Lifecycle Rule.
Resolves to b2:ObjectCreated:*
HideMarkerAll
Listens to all object hide marker creation events.
Resolves to b2:HideMarkerCreated:*
MultiPartUploadCreatedLiveRead
A multipart upload that was started from the S3-Compatible API with Live Read enabled.
Resolves to b2:MultipartUploadCreated:LiveRead
MultiPartUploadCreatedAll
Listens to all object hide marker creation events.
Resolves to b2:MultipartUploadCreated:*