pub struct B2Bucket {
pub account_id: String,
pub bucket_id: String,
pub bucket_name: String,
pub bucket_type: B2BucketType,
pub bucket_info: HashMap<String, String>,
pub cors_rules: Vec<B2CorsRule>,
pub file_lock_configuration: B2ObjectLock<B2BucketFileRetention>,
pub default_server_side_encryption: B2ServerSideEncryption,
pub life_cycle_rules: Option<Vec<B2LifeCycleRules>>,
pub replication_configuration: B2ReplicationConfig,
pub revision: u32,
pub options: Option<Vec<B2BucketOption>>,
}Fields
account_id: StringYour account ID.
bucket_id: StringThe unique identifier of the bucket.
bucket_name: StringThe unique name of the bucket.
bucket_type: B2BucketTypeThe bucket type.
bucket_info: HashMap<String, String>The user data stored with this bucket.
cors_rules: Vec<B2CorsRule>The initial list of CORS rules for this bucket. See CORS Rules for an overview and the rule structure.
file_lock_configuration: B2ObjectLock<B2BucketFileRetention>The Object Lock configuration for this bucket.
This field is filtered based on application key capabilities; the readBucketRetentions capability is required to access the value.
See Object Lock for more details on response structure.
default_server_side_encryption: B2ServerSideEncryptionThe default bucket Server-Side Encryption settings for new files uploaded to this bucket.
This field is filtered based on application key capabilities; the readBucketEncryption capability is required to access the value.
See Server-Side Encryption for more details on response structure
life_cycle_rules: Option<Vec<B2LifeCycleRules>>The initial list of lifecycle rules for this bucket. See Lifecycle Rules for an overview and the rule structure.
replication_configuration: B2ReplicationConfigThe list of replication rules for this bucket. See Cloud Replication Rules.
NOTE: The first time that you configure Cloud Replication, complete the following tasks to ensure that you have the correct permission:
- Verify your email address.
- Have a payment history on file or make a payment.
revision: u32A counter that is updated every time the bucket is modified,
and can be used with the ifRevisionIs parameter to b2_update_bucket to prevent colliding, simultaneous updates.
options: Option<Vec<B2BucketOption>>When present and set to s3, the bucket can be accessed through the S3 Compatible API.